/*
 * Copyright (C) 2005 by Quentin Anciaux
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Library General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Library General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *	@author Quentin Anciaux
 */

package org.w3c.dom.html;

import org.w3c.dom.DOMException;


/**
 * The <code>THEAD</code>,<code>TFOOT</code>, and <code>TBODY</code> elements.
 * 
 * <p>
 * See also the <a
 * href='http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109'>Document
 * Object Model (DOM) Level 2 HTML Specification </a>.
 * </p>
 */
public interface HTMLTableSectionElement
    extends HTMLElement {
    /**
     * Horizontal alignment of data in cells. See the <code>align</code>
     * attribute for HTMLTheadElement for details.
     *
     * @return DOCUMENT ME!
     */
    public String getAlign();

    /**
     * Horizontal alignment of data in cells. See the <code>align</code>
     * attribute for HTMLTheadElement for details.
     *
     * @param align DOCUMENT ME!
     */
    public void setAlign(String align);

    /**
     * Alignment character for cells in a column. See the char attribute
     * definition in HTML 4.01.
     *
     * @return DOCUMENT ME!
     */
    public String getCh();

    /**
     * Alignment character for cells in a column. See the char attribute
     * definition in HTML 4.01.
     *
     * @param ch DOCUMENT ME!
     */
    public void setCh(String ch);

    /**
     * Offset of alignment character. See the charoff attribute definition in
     * HTML 4.01.
     *
     * @return DOCUMENT ME!
     */
    public String getChOff();

    /**
     * Offset of alignment character. See the charoff attribute definition in
     * HTML 4.01.
     *
     * @param chOff DOCUMENT ME!
     */
    public void setChOff(String chOff);

    /**
     * Vertical alignment of data in cells. See the <code>valign</code>
     * attribute for HTMLTheadElement for details.
     *
     * @return DOCUMENT ME!
     */
    public String getVAlign();

    /**
     * Vertical alignment of data in cells. See the <code>valign</code>
     * attribute for HTMLTheadElement for details.
     *
     * @param vAlign DOCUMENT ME!
     */
    public void setVAlign(String vAlign);

    /**
     * The collection of rows in this table section.
     *
     * @return DOCUMENT ME!
     */
    public HTMLCollection getRows();

    /**
     * Insert a row into this section. The new row is inserted immediately
     * before the current <code>index</code> th row in this section. If
     * <code>index</code> is -1 or equal to the number of rows in this
     * section, the new row is appended.
     *
     * @param index The row number where to insert a new row. This index starts
     *        from 0 and is relative only to the rows contained inside this
     *        section, not all the rows in the table.
     *
     * @return The newly created row.
     *
     * @exception DOMException INDEX_SIZE_ERR: Raised if the specified index is
     *            greater than the number of rows of if the index is a
     *            negative number other than -1.
     */
    public HTMLElement insertRow(int index)
        throws DOMException;

    /**
     * Delete a row from this section.
     *
     * @param index The index of the row to be deleted, or -1 to delete the
     *        last row. This index starts from 0 and is relative only to the
     *        rows contained inside this section, not all the rows in the
     *        table.
     *
     * @exception DOMException INDEX_SIZE_ERR: Raised if the specified index is
     *            greater than or equal to the number of rows or if the index
     *            is a negative number other than -1.
     */
    public void deleteRow(int index)
        throws DOMException;
}